==> oscars_mgmnt_clms-0.0.5.dev20240208+28-py3-none-any.whl: oscars_mgmnt_clms/store/elasticsearch.py <==
"""
Created on 30 June 2019

@author: Tonneau Stephane
"""

import logging
import json
from oscars_mgmnt_clms.utils.es_support import ElasticSupport
from oscars_mgmnt_clms.utils.common import OutputWriter

ELASTICSEARCH_LOGGER = logging.getLogger('EsWriter')


class EsWriter(OutputWriter):
    '''Writer that save metadata documents on ES (document by document)'''

    def __init__(self, config, idx, force_index_documents):
        """ Initialisator of the class

        :param config: A configuration object
        :type config: a Config object
        :param idx: the index on which the metadata must be ingested
        :type idx: a string
        :param force_index_documents: indicates whether to use the index operation to insert a document instead of the default upsert
        :type force_index_documents: bool
        """
        OutputWriter.__init__(self)
        self.es_index = idx
        self.force_index_documents = force_index_documents
        self.config = config
        self.es_connector = ElasticSupport(config)

    def output(self, uid, content):
        """ write the content in elastic search

        :param uid: a unique reference
        :type uid: a string
        :param content: a string containing the metadata content to save.
        :type content: a string
        """
        the_uid = uid if (uid is not None) and (len(uid) < 512) else None
        try:
            if self.force_index_documents:
                self.es_connector.single_insert(index=self.es_index, body=content, uid=the_uid)
            else:
                full = json.loads(content)
                partial = removeIngestionTimestamps(json.loads(content))
                self.es_connector.single_upsert(index=self.es_index, doc=partial, upsert=full, uid=the_uid)
            ELASTICSEARCH_LOGGER.info("Metafile %s : ingested in ES", str(the_uid))
        except Exception as err:
            ELASTICSEARCH_LOGGER.error("ES Metafile ingestion issue for %s : %s", str(uid), str(err))
            self.es_connector = ElasticSupport(self.config)
            if self.force_index_documents:
                self.es_connector.single_insert(index=self.es_index, body=content, uid=the_uid)
            else:
                full = json.loads(content)
                partial = removeIngestionTimestamps(json.loads(content))
                self.es_connector.single_upsert(index=self.es_index, doc=partial, upsert=full, uid=the_uid)
            ELASTICSEARCH_LOGGER.error("Retrying succeeds.")
            return


class EsBulkWriter(OutputWriter):
    '''Writer that save metadata documents on ES (in bulk)'''

    def __init__(self, config, idx, nbr, force_index_documents):
        """ Initialisator of the class

        :param config: A configuration object
        :type config: a Config object
        :param idx: the index on which the metadata must be ingested
        :type idx: a string
        :param nbr: the imaximum number of document to ingest at once.
        :type nbr: a number
        :param force_index_documents: indicates whether to use the index operation to insert a document instead of the default upsert
        :type force_index_documents: bool
        """
        OutputWriter.__init__(self)
        self.es_index = idx
        self.force_index_documents = force_index_documents
        self.config = config
        self.actions = []
        self.nbr = nbr
        self.es_connector = ElasticSupport(config)

    def flush(self):
        """ flush the actual bulk write buffer in ES

        """
        try:
            if len(self.actions) >= 0:
                self.es_connector.bulk_insert(self.actions)
                ELASTICSEARCH_LOGGER.info("ES Bulk flush (%s files)", str(len(self.actions)))
        except Exception as err:
            ELASTICSEARCH_LOGGER.error("ES Bulk insert issue (%s) for %s files ... ",
                                       str(err), str(len(self.actions)))
            self.es_connector = ElasticSupport(self.config)
            self.es_connector.bulk_insert(self.actions)
            ELASTICSEARCH_LOGGER.error("Retrying succeeds.")
        self.actions = []

    def output(self, uid, content):
        """ write the content in bulk in elastic search

        :param uid: a unique reference
        :type uid: str
        :param content: a string containing the metadata content to save.
        :type content: str
        """
        the_uid = uid if (uid is not None) and (len(uid) < 512) else None
        if self.force_index_documents:
            self.actions.append(ElasticSupport.as_insert_action(self.es_index, content, the_uid))
        else:
            full = json.loads(content)
            partial = removeIngestionTimestamps(json.loads(content))
            self.actions.append(ElasticSupport.as_upsert_action(self.es_index, doc=partial, upsert=full, uid=the_uid))
        if len(self.actions) >= self.nbr:
            self.flush()


def removeIngestionTimestamps(content):
    """ Removes the timestamps that are updated on ingestion, so the old timestamps can be retained in an update.

    :param content: the metadata of the product as a string
    :type content: dict
    :return: the metadata stripped of the ingestion timestamps
    :rtype: dict
    """
    content["properties"].pop("available")
    content["properties"].pop("published")
    content["properties"]["productInformation"].pop("availabilityTime")

    return content

==> oscars_mgmnt_clms-0.1.3.dev20240513+63-py3-none-any.whl: oscars_mgmnt_clms/store/elasticsearch.py <==
"""
Created on 30 June 2019

@author: Tonneau Stephane
"""

import logging
import json
from oscars_mgmnt_clms.utils.es_support import ElasticSupport
from oscars_mgmnt_clms.utils.common import OutputWriter

ELASTICSEARCH_LOGGER = logging.getLogger("EsWriter")


class EsWriter(OutputWriter):
    """Writer that save metadata documents on ES (document by document)"""

    def __init__(self, config, idx, force_index_documents):
        """Initialisator of the class

        :param config: A configuration object
        :type config: a Config object
        :param idx: the index on which the metadata must be ingested
        :type idx: a string
        :param force_index_documents: indicates whether to use the index operation to insert a document instead of the default upsert
        :type force_index_documents: bool
        """
        OutputWriter.__init__(self)
        self.es_index = idx
        self.force_index_documents = force_index_documents
        self.config = config
        self.es_connector = ElasticSupport(config)

    def output(self, uid, content):
        """write the content in elastic search

        :param uid: a unique reference
        :type uid: a string
        :param content: a string containing the metadata content to save.
        :type content: a string
        """
        the_uid = uid if (uid is not None) and (len(uid) < 512) else None
        try:
            if self.force_index_documents:
                self.es_connector.single_insert(
                    index=self.es_index, body=content, uid=the_uid
                )
            else:
                full = json.loads(content)
                partial = removeIngestionTimestamps(json.loads(content))
                self.es_connector.single_upsert(
                    index=self.es_index, doc=partial, upsert=full, uid=the_uid
                )
            ELASTICSEARCH_LOGGER.info("Metafile %s : ingested in ES", str(the_uid))
        except Exception as err:
            ELASTICSEARCH_LOGGER.error(
                "ES Metafile ingestion issue for %s : %s", str(uid), str(err)
            )
            self.es_connector = ElasticSupport(self.config)
            if self.force_index_documents:
                self.es_connector.single_insert(
                    index=self.es_index, body=content, uid=the_uid
                )
            else:
                full = json.loads(content)
                partial = removeIngestionTimestamps(json.loads(content))
                self.es_connector.single_upsert(
                    index=self.es_index, doc=partial, upsert=full, uid=the_uid
                )
            ELASTICSEARCH_LOGGER.error("Retrying succeeds.")
            return


class EsBulkWriter(OutputWriter):
    """Writer that save metadata documents on ES (in bulk)"""

    def __init__(self, config, idx, nbr, force_index_documents):
        """Initialisator of the class

        :param config: A configuration object
        :type config: a Config object
        :param idx: the index on which the metadata must be ingested
        :type idx: a string
        :param nbr: the imaximum number of document to ingest at once.
        :type nbr: a number
        :param force_index_documents: indicates whether to use the index operation to insert a document instead of the default upsert
        :type force_index_documents: bool
        """
        OutputWriter.__init__(self)
        self.es_index = idx
        self.force_index_documents = force_index_documents
        self.config = config
        self.actions = []
        self.nbr = nbr
        self.es_connector = ElasticSupport(config)

    def flush(self):
        """flush the actual bulk write buffer in ES"""
        try:
            if len(self.actions) >= 0:
                self.es_connector.bulk_insert(self.actions)
                ELASTICSEARCH_LOGGER.info(
                    "ES Bulk flush (%s files)", str(len(self.actions))
                )
        except Exception as err:
            ELASTICSEARCH_LOGGER.error(
                "ES Bulk insert issue (%s) for %s files ... ",
                str(err),
                str(len(self.actions)),
            )
            self.es_connector = ElasticSupport(self.config)
            self.es_connector.bulk_insert(self.actions)
            ELASTICSEARCH_LOGGER.error("Retrying succeeds.")
        self.actions = []

    def output(self, uid, content):
        """write the content in bulk in elastic search

        :param uid: a unique reference
        :type uid: str
        :param content: a string containing the metadata content to save.
        :type content: str
        """
        the_uid = uid if (uid is not None) and (len(uid) < 512) else None
        if self.force_index_documents:
            self.actions.append(
                ElasticSupport.as_insert_action(self.es_index, content, the_uid)
            )
        else:
            full = json.loads(content)
            partial = removeIngestionTimestamps(json.loads(content))
            self.actions.append(
                ElasticSupport.as_upsert_action(
                    self.es_index, doc=partial, upsert=full, uid=the_uid
                )
            )
        if len(self.actions) >= self.nbr:
            self.flush()


def removeIngestionTimestamps(content):
    """Removes the timestamps that are updated on ingestion, so the old timestamps can be retained in an update.

    :param content: the metadata of the product as a string
    :type content: dict
    :return: the metadata stripped of the ingestion timestamps
    :rtype: dict
    """
    content["properties"].pop("available")
    content["properties"].pop("published")
    content["properties"]["productInformation"].pop("availabilityTime")

    return content
